@@ -11,18 +11,26 @@ class Color(object):
         green: int = 0,
         blue: int = 0,
     ):
+        if red > 255:
+            raise ValueError("red must be 0-255")
+        if green > 255:
+            raise ValueError("green must be 0-255")
+        if blue > 255:
+            raise ValueError("blue must be 0-255")
         self.red = red
         self.green = green
         self.blue = blue
 
 
 class Alpha(object):
-    """以 0-255 的整数表示透明度, 不提供序列化方法"""
+    """以 0-255 的整数表示透明度, 255 是不透明, 不提供序列化方法"""
 
     def __init__(
         self,
         alpha: int = 0,
     ):
+        if alpha > 255:
+            raise ValueError("alpha must be 0-255")
         self.alpha = alpha
 
 
