@@ -26,7 +26,9 @@ from Annotations2Sub.tools import (
 
 def main():
     parser = argparse.ArgumentParser(
-        description=_("一个可以把 Youtube Annotations 转换成 ASS 字幕(Sub Station Alpha V4)文件的脚本")
+        description=_(
+            "一个可以把 Youtube Annotation 转换成 ASS 字幕(Advanced SubStation Alpha)文件的脚本"
+        )
     )
     parser.add_argument(
         "queue",
@@ -34,7 +36,7 @@ def main():
         nargs="+",
         metavar=_("文件 或 videoId"),
         help=_(
-            "多个需要转换的文件的文件路径, 或者是多个需要预览, 生成, 从Internet Archive 下载 Annotations 文件 Youtube 视频的 videoId"
+            "多个需要转换的文件的文件路径, 或者是多个需要预览, 生成, 从Internet Archive 下载注释文件 Youtube 视频的 videoId"
         ),
     )
     parser.add_argument(
@@ -78,7 +80,7 @@ def main():
         "-d",
         "--download-for-archive",
         action="store_true",
-        help=_("尝试从 Internet Archive 下载 Annotations 文件"),
+        help=_("尝试从 Internet Archive 下载注释文件"),
     )
     parser.add_argument(
         "-i",
@@ -102,7 +104,7 @@ def main():
         "-u",
         "--unstable",
         action="store_true",
-        help=_("启用不稳定功能, 如 speech 样式, highlightText 样式, 会出现一些问题"),
+        help=_("启用不稳定功能, 会出现一些问题"),
     )
     parser.add_argument(
         "-v",
@@ -138,6 +140,7 @@ def main():
     if args.preview_video or args.generate_video:
         if args.invidious_instances is None:
             print(RedText(_("请指定一个 invidious 实例")))
+            print(_("你可以在这里找一个:"), "https://redirect.invidious.io/")
             exit(1)
         args.download_for_archive = True
         args.embrace_libass = True
@@ -148,7 +151,13 @@ def main():
                 print(RedText(_("{} 不是一个文件").format(filePath)))
                 exit(1)
             try:
-                defusedxml.ElementTree.parse(filePath)
+                tree = defusedxml.ElementTree.parse(filePath)
+                count = 0
+                for each in tree.find("annotations").findall("annotation"):
+                    count += 1
+                if count == 0:
+                    print(RedText(_("{} 没有 Annotation").format(filePath)))
+                    exit(1)
             except:
                 print(RedText(_("{} 不是一个有效的 XML 文件").format(filePath)))
                 print(traceback.format_exc())
@@ -176,12 +185,23 @@ def main():
             print(_("下载 {}").format(url))
             string = urllib.request.urlopen(url).read().decode("utf-8")
             if string == "":
-                print(YellowText(_("{} 可能没有 Annotations").format(videoId)))
+                print(YellowText(_("{} 可能没有 Annotation").format(videoId)))
                 continue
             with open(filePath, "w", encoding="utf-8") as f:
                 f.write(string)
             filePaths.append(filePath)
 
+    if args.embrace_libass and (
+        args.transform_resolution_x == 100 or args.transform_resolution_y == 100
+    ):
+        print(
+            YellowText(
+                _(
+                    "--embrace-libass 需要注意, 如果您的视频不是 16:9, 请使用 --transform-resolution-x --transform-resolution-y, 以确保效果."
+                )
+            )
+        )
+
     outputs = []
     for filePath in filePaths:
         output = filePath + ".ass"
@@ -199,12 +219,15 @@ def main():
             args.transform_resolution_x,
             args.transform_resolution_y,
         )
+        if events == []:
+            print(YellowText(_("{} 没有注释被转换").format(filePath)))
         events.sort(key=lambda event: event.Start)
         sub = Sub()
-        sub.events.events.extend(events)
-        sub.info.info["PlayResX"] = args.transform_resolution_x
-        sub.info.info["PlayResY"] = args.transform_resolution_y
-        sub.styles.styles["Default"].Fontname = args.font
+        sub.events.extend(events)
+        sub.info["PlayResX"] = args.transform_resolution_x
+        sub.info["PlayResY"] = args.transform_resolution_y
+        sub.info["Title"] = filePath
+        sub.styles["Default"].Fontname = args.font
         subString = sub.Dump()
         with open(output, "w", encoding="utf-8") as f:
             f.write(subString)
